==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/Input/wildmidi/translations/wildmidi_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="49"/>
        <source>WildMidi Plugin</source>
        <translation>Plugin WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="54"/>
        <source>Midi Files</source>
        <translation>Arquivos Midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="106"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>Sobre o plugin WildMidi Audio</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="107"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>Plugin Qmmp WildMidi Audio</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="108"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>Este plugin utiliza a biblioteca WildMidi para a reprodução</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="109"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>Preferências do plugin WildMidi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>Configuração do instrumento:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="43"/>
        <source>Sample rate:</source>
        <translation>Frequência:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="50"/>
        <source>Enhanced resampling</source>
        <translation>Amostragem melhorada</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Reverberation</source>
        <translation>Reverberação</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/Input/wildmidi/translations/wildmidi_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="49"/>
        <source>WildMidi Plugin</source>
        <translation>Plugin WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="54"/>
        <source>Midi Files</source>
        <translation>Arquivos Midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="105"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>Sobre o plugin WildMidi Audio</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="106"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>Plugin Qmmp WildMidi Audio</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="107"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>Este plugin utiliza a biblioteca WildMidi para a reprodução</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="108"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WildMidiSettingsDialog</name>
    <message>
        <location filename="../wildmidisettingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>Preferências do plugin WildMidi</translation>
    </message>
    <message>
        <location filename="../wildmidisettingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>Configuração do instrumento:</translation>
    </message>
    <message>
        <location filename="../wildmidisettingsdialog.ui" line="43"/>
        <source>Sample rate:</source>
        <translation>Frequência:</translation>
    </message>
    <message>
        <location filename="../wildmidisettingsdialog.ui" line="50"/>
        <source>Enhanced resampling</source>
        <translation>Amostragem melhorada</translation>
    </message>
    <message>
        <location filename="../wildmidisettingsdialog.ui" line="57"/>
        <source>Reverberation</source>
        <translation>Reverberação</translation>
    </message>
    <message>
        <location filename="../wildmidisettingsdialog.cpp" line="39"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../wildmidisettingsdialog.cpp" line="40"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>
